<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Data::StatusIconSettings</name>
    <message>
        <location filename="../syncthingicons.cpp" line="239"/>
        <source>Misc. notifications</source>
        <translation>杂项通知</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="240"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="241"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="242"/>
        <source>Idle</source>
        <translation>空闲</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="243"/>
        <source>Scanning</source>
        <translation>扫描中</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="244"/>
        <source>Synchronizing</source>
        <translation>同步中</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="245"/>
        <source>Paused</source>
        <translation>已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="246"/>
        <source>Disconnected</source>
        <translation>已断连</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDeviceModel</name>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="95"/>
        <location filename="../syncthingdevicemodel.cpp" line="131"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="97"/>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="133"/>
        <source>Out of Sync items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="139"/>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="141"/>
        <source>Connection type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="143"/>
        <source>Last seen</source>
        <translation>最后在线</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="145"/>
        <source>Compression</source>
        <translation>压缩</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="147"/>
        <source>Certificate</source>
        <translation>证书</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="149"/>
        <source>Introducer</source>
        <translation>介绍人</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="135"/>
        <source>Incoming traffic</source>
        <translation>下载流量</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="137"/>
        <source>Outgoing traffic</source>
        <translation>上传流量</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="151"/>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdevicemodel.cpp" line="166"/>
        <source>%1 item(s), ~ %2</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="183"/>
        <source>local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="183"/>
        <source>remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="188"/>
        <source>unknown or this device</source>
        <translation>未知或本设备</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="164"/>
        <location filename="../syncthingdevicemodel.cpp" line="193"/>
        <source>none</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="195"/>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="195"/>
        <source>no</source>
        <translation>否</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="vanished">已暂停</translation>
    </message>
    <message>
        <source>Unknown status</source>
        <translation type="vanished">未知状态</translation>
    </message>
    <message>
        <source>This device</source>
        <translation type="vanished">本设备</translation>
    </message>
    <message>
        <source>Idle</source>
        <translation type="vanished">空闲</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation type="vanished">已断连</translation>
    </message>
    <message>
        <source>Synchronizing (%1 %, %2)</source>
        <translation type="vanished">同步中 (%1 %, %2)</translation>
    </message>
    <message>
        <source>Synchronizing</source>
        <translation type="vanished">同步中</translation>
    </message>
    <message>
        <source>Out of sync</source>
        <translation type="vanished">未同步</translation>
    </message>
    <message>
        <source>Rejected</source>
        <translation type="vanished">被拒绝</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDirectoryModel</name>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="96"/>
        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="98"/>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
        <source>Global status</source>
        <translation>全局状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
        <source>Local status</source>
        <translation>本地状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
        <source>Shared with</source>
        <translation>分享到</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
        <source>Rescan interval</source>
        <translation>重新扫描间隔</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
        <source>Last scan</source>
        <translation>最后扫描</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="144"/>
        <source>Last file</source>
        <translation>最后更改</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="394"/>
        <source>Override remote changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="397"/>
        <source>Revert local changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Errors</source>
        <translation type="vanished">错误</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="171"/>
        <source>not shared</source>
        <translation>未分享</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
        <location filename="../syncthingdirectorymodel.cpp" line="181"/>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
        <location filename="../syncthingdirectorymodel.cpp" line="191"/>
        <source>none</source>
        <translation>无</translation>
    </message>
    <message numerus="yes">
        <source>%1 item(s) out of sync</source>
        <translation type="vanished">
            <numerusform>%1 项目未同步</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1 and %2 item(s) out of sync</source>
        <translation type="vanished">
            <numerusform>%1 和  %2 项目未同步</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="278"/>
        <source>Deleted at %1</source>
        <translation>于 %1 被删除</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="281"/>
        <source>Updated at %1</source>
        <translation>于 %1 更新</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="148"/>
        <location filename="../syncthingdirectorymodel.cpp" line="293"/>
        <source>Failed items</source>
        <translation>已失败项目</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="146"/>
        <source>Out of Sync items</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
        <source>%1 item(s), ~ %2</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="197"/>
        <source>%1 item(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="199"/>
        <source>%1 and %2 item(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="294"/>
        <source>Click for details</source>
        <translation>点击以获取详情</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="vanished">已暂停</translation>
    </message>
    <message>
        <source>Unshared</source>
        <translation type="vanished">未分享</translation>
    </message>
    <message>
        <source>Unknown status</source>
        <translation type="vanished">未知状态</translation>
    </message>
    <message>
        <source>Idle</source>
        <translation type="vanished">空闲</translation>
    </message>
    <message>
        <source>Waiting to scan</source>
        <translation type="vanished">等待扫描</translation>
    </message>
    <message>
        <source>Scanning (%1 %, %2)</source>
        <translation type="vanished">扫描中 (%1 %, %2)</translation>
    </message>
    <message>
        <source>Scanning (%1 %)</source>
        <translation type="vanished">扫描中 (%1 %)</translation>
    </message>
    <message>
        <source>Scanning</source>
        <translation type="vanished">扫描中</translation>
    </message>
    <message>
        <source>Waiting to sync</source>
        <translation type="vanished">等待同步</translation>
    </message>
    <message>
        <source>Preparing to sync</source>
        <translation type="vanished">准备同步</translation>
    </message>
    <message>
        <source>Synchronizing (%1 %)</source>
        <translation type="vanished">同步中 (%1 %)</translation>
    </message>
    <message>
        <source>Synchronizing</source>
        <translation type="vanished">同步中</translation>
    </message>
    <message>
        <source>Cleaning</source>
        <translation type="vanished">清理中</translation>
    </message>
    <message>
        <source>Waiting to clean</source>
        <translation type="vanished">等待清理</translation>
    </message>
    <message>
        <source>Out of sync</source>
        <translation type="vanished">未同步</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDownloadModel</name>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="95"/>
        <source>Dir/item</source>
        <translation>目录/项目</translation>
    </message>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="97"/>
        <source>Progress</source>
        <translation>进度</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingErrorModel</name>
    <message>
        <location filename="../syncthingerrormodel.cpp" line="62"/>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingerrormodel.cpp" line="64"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingFileModel</name>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="315"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="317"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="319"/>
        <source>Last modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="321"/>
        <source>Ignore pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="369"/>
        <source>%1 elements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="232"/>
        <source>Exists locally and globally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="234"/>
        <source>Exists only globally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="236"/>
        <source>Exists only locally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="238"/>
        <source>Exists globally and perhaps locally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="240"/>
        <source>Exists locally and perhaps globally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="242"/>
        <source>Does not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="486"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="489"/>
        <source>Deselect recursively</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="489"/>
        <source>Select recursively</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="491"/>
        <source>Deselect single item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="491"/>
        <source>Select single item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="493"/>
        <source>Open local version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="493"/>
        <source>Copy local path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="493"/>
        <source>Browse locally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="778"/>
        <source>Select items to sync/ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="780"/>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="785"/>
        <source>Discard staged changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="795"/>
        <source>Uncheck all and discard staged changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="797"/>
        <source>Discard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="809"/>
        <source>Ignore checked items (and their children)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="823"/>
        <source>Include checked items (and their children)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="862"/>
        <source>Remove ignore patterns matching checked items (may affect other items as well)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="831"/>
        <source>Include all items by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="816"/>
        <source>Ignore and locally delete checked items (and their children)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="831"/>
        <source>Ignore all items by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="890"/>
        <source>Review and apply staged changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="892"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="900"/>
        <source>Do you want to apply the following changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="908"/>
        <source>Cannot apply ignore patterns while a previous request for ignore patterns is still pending.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="916"/>
        <source>Unable to change ignore patterns:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="982"/>
        <source>Ignore patterns have been changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="985"/>
        <source>Ignore patterns have been changed but the following local files could not be deleted:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="1155"/>
        <source>Cannot query ignore patterns while a previous request for ignore patterns is still pending.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingRecentChangesModel</name>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="69"/>
        <source>Action</source>
        <translation>操作</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
        <source>Folder</source>
        <translation>目录</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="117"/>
        <source>Locally</source>
        <translation>本地</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="117"/>
        <source>Remotely</source>
        <translation>远程</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingStatusComputionModel</name>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="38"/>
        <source>Local dir is scanning</source>
        <translation>正在扫描本地目录</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="40"/>
        <source>Local dir is synchronizing</source>
        <translation>正在同步本地目录</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="42"/>
        <source>Remote dir has outstanding progress</source>
        <translation>远程目录有未完成进度</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="44"/>
        <source>No remote device connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="46"/>
        <source>A device is paused</source>
        <translation>一个设备已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="48"/>
        <source>Local dir is out of sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="50"/>
        <source>Unread notification present</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
